uniform sampler2D tex0;
uniform mediump vec2 size_tex0;
uniform mediump vec4 filter_settings; //x is distance multiplier, y is intensity

precision mediump float;

varying mediump vec2 varTexcoord0;
varying mediump vec4 varColor;

void main(void)
{
	float blurSize=filter_settings.x/size_tex0.x;
	vec3 thisCol = texture2D(tex0, vec2(varTexcoord0.x, varTexcoord0.y)).rgb;
	vec3 sum = vec3(0.0);	

	// blur in y (vertical)
	// take nine samples, with the distance blurSize between them
	sum += texture2D(tex0, vec2(varTexcoord0.x - 4.0*blurSize, varTexcoord0.y)).rgb * 0.05;
	sum += texture2D(tex0, vec2(varTexcoord0.x - 3.0*blurSize, varTexcoord0.y)).rgb * 0.09;
	sum += texture2D(tex0, vec2(varTexcoord0.x - 2.0*blurSize, varTexcoord0.y)).rgb * 0.12;
	sum += texture2D(tex0, vec2(varTexcoord0.x - blurSize, varTexcoord0.y)).rgb * 0.15;
	sum += thisCol * 0.16;
	sum += texture2D(tex0, vec2(varTexcoord0.x + blurSize, varTexcoord0.y)).rgb * 0.15;
	sum += texture2D(tex0, vec2(varTexcoord0.x + 2.0*blurSize, varTexcoord0.y)).rgb * 0.12;
	sum += texture2D(tex0, vec2(varTexcoord0.x + 3.0*blurSize, varTexcoord0.y)).rgb * 0.09;
	sum += texture2D(tex0, vec2(varTexcoord0.x + 4.0*blurSize, varTexcoord0.y)).rgb * 0.05;

	vec3 blend = sum*filter_settings.y+thisCol*(1.0-filter_settings.y);
	float averageValue=(blend.r+blend.g+blend.b)/3.0;
	float greyScaleIntensity=filter_settings.z;
	vec3 finalCol=blend*(1.0-greyScaleIntensity)+vec3(averageValue, averageValue, averageValue)*greyScaleIntensity;
	gl_FragColor = vec4(finalCol, 1.0)*varColor;
}
